@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+import myhdl
 from myhdl import *
 
 WIDTH=4
@@ -23,7 +25,7 @@ def dec():
 def tb_stimulus():
     # My logic happens on posedge, so I'll perform all checks on negedge.
     yield clk.negedge
-    for x_val in xrange(-2**WIDTH, 2**WIDTH):
+    for x_val in range(-2**WIDTH, 2**WIDTH):
         #print('x_val={} x.next={}'.format(x_val, x_val % 2**WIDTH))
         x.next = x_val % 2**WIDTH
         yield clk.negedge
@@ -35,6 +37,6 @@ def tb_stimulus():
 tb = instances()
 
 def test_bug_44():
-    print instances()
+    print(instances())
     Simulation(tb).run()
 
