@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+import myhdl
 from myhdl import *
 
 def gray_counter (clk, reset, enable, gray_count):
