@@ -2,7 +2,9 @@
 # -*- coding: utf-8 -*-
 """Failed VHDL code example
 """
+from __future__ import absolute_import
 
+import myhdl
 from myhdl import *
 from myhdl.conversion import verify
 
@@ -33,7 +35,7 @@ def Logic(flags, position):
         yield delay(10)
         conc.next = concat(flags, position)
         yield delay(10)
-        print conc 
+        print(conc) 
     return doit
 
 def test_issue_10_2():
