@@ -1,5 +1,8 @@
+from __future__ import absolute_import
+import myhdl
 from myhdl import *
 
+@block
 def constants(v, u, x, y, z, a):
 
     b = Signal(bool(0))
@@ -23,5 +26,4 @@ u = Signal(intbv(0)[8:])
 v = Signal(intbv(0, min=-3, max=9))
 
 def test_constants():
-    assert conversion.analyze(constants, v, u, x, y, z, a) == 0 
-        
+    assert constants(v, u, x, y, z, a).analyze_convert() == 0 
