@@ -1,6 +1,8 @@
+from __future__ import absolute_import
 import os
 path = os.path
 
+import myhdl
 from myhdl import *
 
 
@@ -39,19 +41,19 @@ def NonlocalBench():
         yield clk.negedge
         reset.next = 1
         yield clk.negedge
-        print qout
+        print(qout)
         assert qout == ONE
         reset.next = 0
         for i in range(100):
             yield clk.negedge
-            print qout
+            print(qout)
         init.next = 1
         yield clk.negedge
         assert qout == ALL_ONES
-        print qout
+        print(qout)
         init.next = 0
         for i in range(300):
-            print qout
+            print(qout)
         raise StopSimulation()
         
     return scrambler, clkgen, stimulus
